==> google-cloud-talent-2.6.0.tar.gz: google-cloud-talent-2.6.0/google/cloud/talent_v4beta1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.application_service import (
    ApplicationServiceAsyncClient,
    ApplicationServiceClient,
)
from .services.company_service import CompanyServiceAsyncClient, CompanyServiceClient
from .services.completion import CompletionAsyncClient, CompletionClient
from .services.event_service import EventServiceAsyncClient, EventServiceClient
from .services.job_service import JobServiceAsyncClient, JobServiceClient
from .services.profile_service import ProfileServiceAsyncClient, ProfileServiceClient
from .services.tenant_service import TenantServiceAsyncClient, TenantServiceClient
from .types.application import Application
from .types.application_service import (
    CreateApplicationRequest,
    DeleteApplicationRequest,
    GetApplicationRequest,
    ListApplicationsRequest,
    ListApplicationsResponse,
    UpdateApplicationRequest,
)
from .types.common import (
    AvailabilitySignalType,
    BatchOperationMetadata,
    Certification,
    CommuteMethod,
    CompanySize,
    CompensationInfo,
    ContactInfoUsage,
    CustomAttribute,
    DegreeType,
    DeviceInfo,
    EmploymentType,
    HtmlSanitization,
    Interview,
    JobBenefit,
    JobCategory,
    JobLevel,
    Location,
    Outcome,
    PostingRegion,
    Rating,
    RequestMetadata,
    ResponseMetadata,
    Skill,
    SkillProficiencyLevel,
    SpellingCorrection,
    TimestampRange,
    Visibility,
)
from .types.company import Company
from .types.company_service import (
    CreateCompanyRequest,
    DeleteCompanyRequest,
    GetCompanyRequest,
    ListCompaniesRequest,
    ListCompaniesResponse,
    UpdateCompanyRequest,
)
from .types.completion_service import CompleteQueryRequest, CompleteQueryResponse
from .types.event import ClientEvent, JobEvent, ProfileEvent
from .types.event_service import CreateClientEventRequest
from .types.filters import (
    ApplicationDateFilter,
    ApplicationJobFilter,
    ApplicationOutcomeNotesFilter,
    AvailabilityFilter,
    CandidateAvailabilityFilter,
    CommuteFilter,
    CompensationFilter,
    EducationFilter,
    EmployerFilter,
    JobQuery,
    JobTitleFilter,
    LocationFilter,
    PersonNameFilter,
    ProfileQuery,
    SkillFilter,
    TimeFilter,
    WorkExperienceFilter,
)
from .types.histogram import HistogramQuery, HistogramQueryResult
from .types.job import Job
from .types.job_service import (
    BatchCreateJobsRequest,
    BatchDeleteJobsRequest,
    BatchUpdateJobsRequest,
    CreateJobRequest,
    DeleteJobRequest,
    GetJobRequest,
    JobOperationResult,
    JobView,
    ListJobsRequest,
    ListJobsResponse,
    SearchJobsRequest,
    SearchJobsResponse,
    UpdateJobRequest,
)
from .types.profile import (
    Activity,
    AdditionalContactInfo,
    Address,
    AvailabilitySignal,
    Degree,
    EducationRecord,
    Email,
    EmploymentRecord,
    Patent,
    PersonalUri,
    PersonName,
    Phone,
    Profile,
    Publication,
    Resume,
)
from .types.profile_service import (
    CreateProfileRequest,
    DeleteProfileRequest,
    GetProfileRequest,
    ListProfilesRequest,
    ListProfilesResponse,
    SearchProfilesRequest,
    SearchProfilesResponse,
    SummarizedProfile,
    UpdateProfileRequest,
)
from .types.tenant import Tenant
from .types.tenant_service import (
    CreateTenantRequest,
    DeleteTenantRequest,
    GetTenantRequest,
    ListTenantsRequest,
    ListTenantsResponse,
    UpdateTenantRequest,
)

__all__ = (
    "ApplicationServiceAsyncClient",
    "CompanyServiceAsyncClient",
    "CompletionAsyncClient",
    "EventServiceAsyncClient",
    "JobServiceAsyncClient",
    "ProfileServiceAsyncClient",
    "TenantServiceAsyncClient",
    "Activity",
    "AdditionalContactInfo",
    "Address",
    "Application",
    "ApplicationDateFilter",
    "ApplicationJobFilter",
    "ApplicationOutcomeNotesFilter",
    "ApplicationServiceClient",
    "AvailabilityFilter",
    "AvailabilitySignal",
    "AvailabilitySignalType",
    "BatchCreateJobsRequest",
    "BatchDeleteJobsRequest",
    "BatchOperationMetadata",
    "BatchUpdateJobsRequest",
    "CandidateAvailabilityFilter",
    "Certification",
    "ClientEvent",
    "CommuteFilter",
    "CommuteMethod",
    "Company",
    "CompanyServiceClient",
    "CompanySize",
    "CompensationFilter",
    "CompensationInfo",
    "CompleteQueryRequest",
    "CompleteQueryResponse",
    "CompletionClient",
    "ContactInfoUsage",
    "CreateApplicationRequest",
    "CreateClientEventRequest",
    "CreateCompanyRequest",
    "CreateJobRequest",
    "CreateProfileRequest",
    "CreateTenantRequest",
    "CustomAttribute",
    "Degree",
    "DegreeType",
    "DeleteApplicationRequest",
    "DeleteCompanyRequest",
    "DeleteJobRequest",
    "DeleteProfileRequest",
    "DeleteTenantRequest",
    "DeviceInfo",
    "EducationFilter",
    "EducationRecord",
    "Email",
    "EmployerFilter",
    "EmploymentRecord",
    "EmploymentType",
    "EventServiceClient",
    "GetApplicationRequest",
    "GetCompanyRequest",
    "GetJobRequest",
    "GetProfileRequest",
    "GetTenantRequest",
    "HistogramQuery",
    "HistogramQueryResult",
    "HtmlSanitization",
    "Interview",
    "Job",
    "JobBenefit",
    "JobCategory",
    "JobEvent",
    "JobLevel",
    "JobOperationResult",
    "JobQuery",
    "JobServiceClient",
    "JobTitleFilter",
    "JobView",
    "ListApplicationsRequest",
    "ListApplicationsResponse",
    "ListCompaniesRequest",
    "ListCompaniesResponse",
    "ListJobsRequest",
    "ListJobsResponse",
    "ListProfilesRequest",
    "ListProfilesResponse",
    "ListTenantsRequest",
    "ListTenantsResponse",
    "Location",
    "LocationFilter",
    "Outcome",
    "Patent",
    "PersonName",
    "PersonNameFilter",
    "PersonalUri",
    "Phone",
    "PostingRegion",
    "Profile",
    "ProfileEvent",
    "ProfileQuery",
    "ProfileServiceClient",
    "Publication",
    "Rating",
    "RequestMetadata",
    "ResponseMetadata",
    "Resume",
    "SearchJobsRequest",
    "SearchJobsResponse",
    "SearchProfilesRequest",
    "SearchProfilesResponse",
    "Skill",
    "SkillFilter",
    "SkillProficiencyLevel",
    "SpellingCorrection",
    "SummarizedProfile",
    "Tenant",
    "TenantServiceClient",
    "TimeFilter",
    "TimestampRange",
    "UpdateApplicationRequest",
    "UpdateCompanyRequest",
    "UpdateJobRequest",
    "UpdateProfileRequest",
    "UpdateTenantRequest",
    "Visibility",
    "WorkExperienceFilter",
)

==> google-cloud-talent-2.7.1.tar.gz: google-cloud-talent-2.7.1/google/cloud/talent_v4beta1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.company_service import CompanyServiceAsyncClient, CompanyServiceClient
from .services.completion import CompletionAsyncClient, CompletionClient
from .services.event_service import EventServiceAsyncClient, EventServiceClient
from .services.job_service import JobServiceAsyncClient, JobServiceClient
from .services.tenant_service import TenantServiceAsyncClient, TenantServiceClient
from .types.common import (
    BatchOperationMetadata,
    CommuteMethod,
    CompanySize,
    CompensationInfo,
    CustomAttribute,
    DegreeType,
    DeviceInfo,
    EmploymentType,
    HtmlSanitization,
    JobBenefit,
    JobCategory,
    JobLevel,
    Location,
    PostingRegion,
    RequestMetadata,
    ResponseMetadata,
    SpellingCorrection,
    TimestampRange,
    Visibility,
)
from .types.company import Company
from .types.company_service import (
    CreateCompanyRequest,
    DeleteCompanyRequest,
    GetCompanyRequest,
    ListCompaniesRequest,
    ListCompaniesResponse,
    UpdateCompanyRequest,
)
from .types.completion_service import CompleteQueryRequest, CompleteQueryResponse
from .types.event import ClientEvent, JobEvent
from .types.event_service import CreateClientEventRequest
from .types.filters import CommuteFilter, CompensationFilter, JobQuery, LocationFilter
from .types.histogram import HistogramQuery, HistogramQueryResult
from .types.job import Job
from .types.job_service import (
    BatchCreateJobsRequest,
    BatchDeleteJobsRequest,
    BatchUpdateJobsRequest,
    CreateJobRequest,
    DeleteJobRequest,
    GetJobRequest,
    JobOperationResult,
    JobView,
    ListJobsRequest,
    ListJobsResponse,
    SearchJobsRequest,
    SearchJobsResponse,
    UpdateJobRequest,
)
from .types.tenant import Tenant
from .types.tenant_service import (
    CreateTenantRequest,
    DeleteTenantRequest,
    GetTenantRequest,
    ListTenantsRequest,
    ListTenantsResponse,
    UpdateTenantRequest,
)

__all__ = (
    "CompanyServiceAsyncClient",
    "CompletionAsyncClient",
    "EventServiceAsyncClient",
    "JobServiceAsyncClient",
    "TenantServiceAsyncClient",
    "BatchCreateJobsRequest",
    "BatchDeleteJobsRequest",
    "BatchOperationMetadata",
    "BatchUpdateJobsRequest",
    "ClientEvent",
    "CommuteFilter",
    "CommuteMethod",
    "Company",
    "CompanyServiceClient",
    "CompanySize",
    "CompensationFilter",
    "CompensationInfo",
    "CompleteQueryRequest",
    "CompleteQueryResponse",
    "CompletionClient",
    "CreateClientEventRequest",
    "CreateCompanyRequest",
    "CreateJobRequest",
    "CreateTenantRequest",
    "CustomAttribute",
    "DegreeType",
    "DeleteCompanyRequest",
    "DeleteJobRequest",
    "DeleteTenantRequest",
    "DeviceInfo",
    "EmploymentType",
    "EventServiceClient",
    "GetCompanyRequest",
    "GetJobRequest",
    "GetTenantRequest",
    "HistogramQuery",
    "HistogramQueryResult",
    "HtmlSanitization",
    "Job",
    "JobBenefit",
    "JobCategory",
    "JobEvent",
    "JobLevel",
    "JobOperationResult",
    "JobQuery",
    "JobServiceClient",
    "JobView",
    "ListCompaniesRequest",
    "ListCompaniesResponse",
    "ListJobsRequest",
    "ListJobsResponse",
    "ListTenantsRequest",
    "ListTenantsResponse",
    "Location",
    "LocationFilter",
    "PostingRegion",
    "RequestMetadata",
    "ResponseMetadata",
    "SearchJobsRequest",
    "SearchJobsResponse",
    "SpellingCorrection",
    "Tenant",
    "TenantServiceClient",
    "TimestampRange",
    "UpdateCompanyRequest",
    "UpdateJobRequest",
    "UpdateTenantRequest",
    "Visibility",
)
